# Copyright (C) 2022 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from typing import Any

from cbra.core import Application
from cbra.core.utils import parent_signature
from .aortaendpoint import AortaEndpoint


class Service(Application):
    __module__: str = 'cbra.ext.google'

    @parent_signature(Application.__init__)
    def __init__(self, *args: Any, **kwargs: Any):
        super().__init__(*args, **kwargs)
        self.add(AortaEndpoint, path="/.well-known/aorta")


# Copyright (C) 2021-2023 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
from .abortable import Abortable
from .conflict import Conflict
from .forbidden import Forbidden
from .hints import PolymorphicIterable
from .iauthorizationcontext import IAuthorizationContext
from .iauthorizationcontextfactory import IAuthorizationContextFactory
from .icredential import ICredential
from .icredentialverifier import ICredentialVerifier
from .ideferred import IDeferred
from .idependant import IDependant
from .iendpoint import IEndpoint
from .integerpathparameter import IntegerPathParameter
from .iroutable import IRoutable
from .iprincipal import IPrincipal
from .iprincipalintrospecter import IPrincipalIntrospecter
from .isubject import ISubject
from .isubjectresolver import ISubjectResolver
from .jsonwebtoken import JSONWebToken
from .jsonwebtokenprincipal import JSONWebTokenPrincipal
from .mutablesignature import MutableSignature
from .nullprincipal import NullPrincipal
from .nullsubject import NullSubject
from .nullsubjectesolver import NullSubjectResolver
from .notauthorized import NotAuthorized
from .notfound import NotFound
from .operation import Operation
from .oidcprincipal import OIDCPrincipal
from .pathparameter import PathParameter
from .principal import Principal
from .rfc9068principal import RFC9068Principal
from .unauthenticatedauthorizationcontext import UnauthenticatedAuthorizationContext
from .uuidpathparameter import UUIDPathParameter


__all__: list[str] = [
    'Abortable',
    'Conflict',
    'Forbidden',
    'ICredential',
    'ICredentialVerifier',
    'IDependant',
    'IDeferred',
    'IAuthorizationContext',
    'IAuthorizationContextFactory',
    'IEndpoint',
    'IntegerPathParameter',
    'IPrincipal',
    'IPrincipalIntrospecter',
    'IRoutable',
    'ISubject',
    'ISubjectResolver',
    'JSONWebToken',
    'JSONWebTokenPrincipal',
    'MutableSignature',
    'NotAuthorized',
    'NotFound',
    'NullPrincipal',
    'NullSubject',
    'NullSubjectResolver',
    'Operation',
    'OIDCPrincipal',
    'PathParameter',
    'PolymorphicIterable',
    'Principal',
    'RFC9068Principal',
    'UnauthenticatedAuthorizationContext',
    'UUIDPathParameter',
]